<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exsl="http://exslt.org/common"
    xmlns:str="http://exslt.org/strings"
    extension-element-prefixes="str">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    <xsl:import href="tpl_prepend_url_6100.xsl" />
    
    <xsl:output method="text"/>
    
    <xsl:param name="locationHref" />
    <xsl:param name="categoryHref" />
    <xsl:param name="sequence" />
    <xsl:param name="categoryAbbr" />
    
    <!--transform CCListingsContainer-->
    <xsl:template match="/">
        {
        "listings": <xsl:call-template name="tpl_listings"/>,
        <xsl:variable name="NumPosts">
            <xsl:choose>
                <xsl:when test="//key[text()='NumPosts']/following-sibling::*[1]/text()!=''">
                    <xsl:value-of select="sum(//key[text()='NumPosts']/following-sibling::*[1]/text())"/>
                </xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="geocoded">
            <xsl:choose>
                <xsl:when test="//key[text()='geocoded']/following-sibling::*[1]/text()!=''">
                    <xsl:value-of select="number(//key[text()='geocoded']/following-sibling::*[1]/text())"/>
                </xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        
        "total_count": <xsl:value-of select="$NumPosts + $geocoded" />
        }
    </xsl:template>
    
    <!--transform CCListingData-->
    <xsl:template name="tpl_listings">
        [
        <xsl:for-each select=".//*[local-name()='array']">
            <xsl:for-each select=".//*[local-name()='array']">
                <xsl:for-each select=".//*[local-name()='dict']">
                    {
                    "posting_id": "<xsl:value-of select="key[text()='PostingID']/following-sibling::*[1]/text()"/>",
                    "title": "<xsl:call-template name="tpl_sanitize">
                        <xsl:with-param name="text" select="key[text()='PostingTitle']/following-sibling::*[1]/text()"/>
                    </xsl:call-template>",
                    "link": "<xsl:call-template name="tpl_prepend_href_with_base_url">
                        <xsl:with-param name="href" select="key[text()='PostingURL']/following-sibling::*[1]/text()"/>
                    </xsl:call-template>",
                    <xsl:variable name="price"><xsl:value-of select="key[text()='price']/following-sibling::*[1]/text()"/></xsl:variable>
                    "price": "<xsl:if test="number($price)>0">
                        <xsl:if test="not(contains('ppp w4w w4m m4w m4m msr cas mis rnr', $categoryAbbr))">
                            <xsl:value-of select="'$'"/>
                        </xsl:if>
                        <xsl:value-of select="$price"/></xsl:if>",
                    "thumbnail_link":
                    <xsl:variable name="thumbnail">
                        <xsl:value-of select="str:replace(key[text()='ImageThumb']/following-sibling::*[1]/text(),'_50x50c.jpg','_300x300.jpg')"/>
                    </xsl:variable>
                    "<xsl:choose>
                        <xsl:when test="contains($thumbnail,',')">
                            <xsl:value-of select="substring-before($thumbnail,',')"/><xsl:value-of select="'_300x300.jpg'" />
                        </xsl:when>
                        <xsl:otherwise><xsl:value-of select="$thumbnail"/></xsl:otherwise>
                    </xsl:choose>",
                    "location_href": "<xsl:value-of select="$locationHref"/>",
                    "category_href": "<xsl:value-of select="$categoryHref"/>",
                    "geo_cluster_info": <xsl:call-template name="tpl_geocluster_info"></xsl:call-template>,
                    "grouping_info": <xsl:call-template name="tpl_grouping_info"></xsl:call-template>
                    }
                    <xsl:if test="position()!=last()">,</xsl:if>
                </xsl:for-each>
            </xsl:for-each>
        </xsl:for-each>
        
        ]
    </xsl:template>
    
    <!--transform CCListingGeoClusterInfo-->
    <xsl:template name="tpl_geocluster_info">
        {
        "num_posts":
        <xsl:choose>
            <xsl:when test="key[text()='NumPosts']">
                <xsl:value-of select="key[text()='NumPosts']/following-sibling::*[1]/text()"/>
            </xsl:when>
            <xsl:otherwise>1</xsl:otherwise>
        </xsl:choose>,
        <xsl:if test="key[text()='url']">
            "link": "<xsl:call-template name="tpl_prepend_href_with_base_url">
                <xsl:with-param name="href" select="key[text()='url']/following-sibling::*[1]/text()"/>
            </xsl:call-template>",
        </xsl:if>
        "latitude": <xsl:value-of select="key[text()='Latitude']/following-sibling::*[1]/text()"/>,
        "longitude": <xsl:value-of select="key[text()='Longitude']/following-sibling::*[1]/text()"/>
        }
    </xsl:template>
    
    <!--transform CCListingGroupingInfo-->
    <xsl:template name="tpl_grouping_info">
        {
        "ignore_title_duplicates": 1,
        "sequence": <xsl:value-of select="$sequence"/>
        }
    </xsl:template>
    
</xsl:stylesheet>

